import error_explainer
from thonny import get_workbench
from thonny.assistance import ProgramAnalyzer, add_program_analyzer


class ErrorExplainer(ProgramAnalyzer):
    def is_enabled(self):
        return get_workbench().get_option("assistance.use_error_explainer")

    def start_analysis(self, main_file_path, imported_file_paths):
        found_errors = error_explainer.check_runner.run_checks(main_file_path)
        warnings = []
        for error in found_errors:
            warnings.append({
                    "filename": main_file_path,
                    "msg": error,
            })
        self.completion_handler(self, warnings)


def load_plugin():
    for k, v in error_explainer.messages._messages.items():
        error_explainer.messages.overwrite_message(k, v.replace("\n", " "))

    get_workbench().set_default("assistance.use_error_explainer", True)
    get_workbench().add_command(command_id="error-explainer",
                                menu_name="tools",
                                command_label="error-explainer enabled?",
                                flag_name="assistance.use_error_explainer")
    add_program_analyzer(ErrorExplainer)



import setuptools
import os.path

setupdir = os.path.dirname(__file__)

with open("README.md", "r") as rm:
    long_description = rm.read()

requirements = []
for line in open(os.path.join(setupdir, "requirements.txt"), encoding="UTF-8"):
    if line.strip() and not line.startswith("#"):
        requirements.append(line)

setuptools.setup(
    name="thonny-error-explainer",
    version="0.5",
    description="Thonny plugin for error-explainer",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Kaarel Loide",
    author_email="kaarel.loide@gmail.com",
    url="https://github.com/K44rel/thonny-error-explainer-plugin",
    packages=["thonnycontrib.error-explainer"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    install_requires=requirements,
)